<?php
namespace Pinpoint\StackAdapt\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Sales\Model\Order;
use Magento\Store\Model\ScopeInterface;
use Psr\Log\LoggerInterface;

class Config extends AbstractHelper
{
    const STACKADAPT_ENABLE_XML_PATH = 'stackadapt_pixel/general/enable';
    const STACKADAPT_PIXEL_CODE_XML_PATH = 'stackadapt_pixel/general/code';

    /**
     * @var Order
     */
    protected $orderModel;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * Constructor
     *
     * @param Context         $context
     * @param Order           $orderModel
     * @param LoggerInterface $logger
     */
    public function __construct(
        Context $context,
        Order $orderModel,
        LoggerInterface $logger
    ) {
        parent::__construct($context);
        $this->orderModel = $orderModel;
        $this->logger = $logger;
    }

    /**
     * Check if StackAdapter Integration is enabled.
     *
     * @return mixed
     */
    public function isEnabled()
    {
        return $this->scopeConfig->getValue(self::STACKADAPT_ENABLE_XML_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * Get Pixel code
     *
     * @param string $orderIncrementId
     * @return string
     */
    public function getPixelCode(string $orderIncrementId)
    {
        $pixelCodeScript = '';
        $order = $this->getOrder($orderIncrementId);

        $pixelCode = $this->scopeConfig->getValue(self::STACKADAPT_PIXEL_CODE_XML_PATH, ScopeInterface::SCOPE_STORE);
        if ($order && !empty($pixelCode)) {
            $pixelCodeScript = __($pixelCode, $order->getGrandTotal());
        }

        return $pixelCodeScript;
    }

    /**
     * Get Pixel code
     *
     * @param string $orderIncrementId
     * @return Order|false
     */
    public function getOrder(string $orderIncrementId)
    {
        try {
            $order = $this->orderModel->loadByIncrementId($orderIncrementId);
            if ($order->getId()) {
                return $order;
            }
        } catch (\Exception $e) {
            $this->logger->log($e->getMessage());
        }

        return false;
    }
}
